==> qmmp_0.3.1.orig.tar.gz: qmmp-0.3.1/src/plugins/General/lyrics/translations/lyrics_plugin_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs">
<context>
    <name>Lyrics</name>
    <message>
        <location filename="../lyrics.cpp" line="35"/>
        <source>View Lyrics</source>
        <translation>Zobrazit text</translation>
    </message>
    <message>
        <location filename="../lyrics.cpp" line="36"/>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
</context>
<context>
    <name>LyricsFactory</name>
    <message>
        <location filename="../lyricsfactory.cpp" line="29"/>
        <source>Lyrics Plugin</source>
        <translation>Modul pro texty písní</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="50"/>
        <source>About Lyrics Plugin</source>
        <translation>O modulu pro texty písní</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="51"/>
        <source>Qmmp Lyrics Plugin</source>
        <translation>Modul Qmmp pro texty písní</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="53"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilja Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="52"/>
        <source>This plugin retrieves lyrics from lyricsplugin.com</source>
        <translation>Tento modul získává texty písní z lyricsplugin.com</translation>
    </message>
</context>
<context>
    <name>LyricsWindow</name>
    <message>
        <location filename="../lyricswindow.cpp" line="113"/>
        <source>Lyrics: %1 - %2</source>
        <translation>Text: %1 - %2</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="88"/>
        <location filename="../lyricswindow.ui" line="67"/>
        <source>No connection</source>
        <translation>Nespojeno</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="75"/>
        <source>Not found</source>
        <translation>Nenalezeno</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="91"/>
        <source>Looking up host...</source>
        <translation>Vyhledávám hostitele...</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="94"/>
        <source>Connecting...</source>
        <translation>Připojuji se...</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="97"/>
        <source>Sending request...</source>
        <translation>Zasílám požadavek...</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="100"/>
        <source>Receiving</source>
        <translation>Příjímám</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="103"/>
        <source>Connected</source>
        <translation>Připojeno</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="106"/>
        <source>Closing connection...</source>
        <translation>Zavírám spojení...</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="14"/>
        <source>Lyrics Plugin</source>
        <translation>Modul pro texty písní</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="31"/>
        <source>Artist:</source>
        <translation>Umělec:</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="41"/>
        <source>Title:</source>
        <translation>Název:</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="51"/>
        <source>Search</source>
        <translation>Hledat</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="87"/>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
</context>
</TS>

==> qmmp_0.4.3.orig.tar.gz: qmmp-0.4.3/src/plugins/General/lyrics/translations/lyrics_plugin_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs">
<context>
    <name>Lyrics</name>
    <message>
        <location filename="../lyrics.cpp" line="35"/>
        <source>View Lyrics</source>
        <translation>Zobrazit text</translation>
    </message>
    <message>
        <location filename="../lyrics.cpp" line="36"/>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
</context>
<context>
    <name>LyricsFactory</name>
    <message>
        <location filename="../lyricsfactory.cpp" line="29"/>
        <source>Lyrics Plugin</source>
        <translation>Modul pro texty písní</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="50"/>
        <source>About Lyrics Plugin</source>
        <translation>O modulu pro texty písní</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="51"/>
        <source>Qmmp Lyrics Plugin</source>
        <translation>Modul Qmmp pro texty písní</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="53"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilja Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="52"/>
        <source>This plugin retrieves lyrics from lyricsplugin.com</source>
        <translation>Tento modul získává texty písní z lyricsplugin.com</translation>
    </message>
</context>
<context>
    <name>LyricsWindow</name>
    <message>
        <location filename="../lyricswindow.cpp" line="64"/>
        <source>Done</source>
        <translation>Hotovo</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="67"/>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="127"/>
        <source>Lyrics: %1 - %2</source>
        <translation>Text: %1 - %2</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="60"/>
        <source>No connection</source>
        <translation>Nespojeno</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="115"/>
        <source>Not found</source>
        <translation>Nenalezeno</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="96"/>
        <location filename="../lyricswindow.cpp" line="126"/>
        <source>Receiving</source>
        <translation>Příjímám</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="14"/>
        <source>Lyrics Plugin</source>
        <translation>Modul pro texty písní</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="31"/>
        <source>Artist:</source>
        <translation>Umělec:</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="41"/>
        <source>Title:</source>
        <translation>Název:</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="51"/>
        <source>Search</source>
        <translation>Hledat</translation>
    </message>
</context>
</TS>
